@@ -18,9 +18,14 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkconfig.endpoint import endpoint_data
 
 class DescribeConfigurationRecorderRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Config', '2019-01-08', 'DescribeConfigurationRecorder','config')
-		self.set_method('GET')
\ No newline at end of file
+		self.set_method('GET')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
